@@ -8,7 +8,7 @@ test_that("reformat_GSOD file_list parameter reformats data properly", {
   ftp_base <- "ftp://ftp.ncdc.noaa.gov/pub/data/gsod/1960/"
   test_files <- c("066000-99999-1960.op.gz", "066200-99999-1960.op.gz")
   dest <- tempdir()
-  destinations <- paste0(dest, "/", test_files)
+  destinations <- file.path(dest, test_files)
 
   Map(function(u, d) download.file(u, d, mode = "wb"),
       paste0(ftp_base, test_files), destinations)
